==> open-cluster-management-apps-model-6.6.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/SubscriptionSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1.Placement;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1.PlacementFluent;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.util.Collection;

 /**
  * Generated
  */
public interface SubscriptionSpecFluent<A extends SubscriptionSpecFluent<A>> extends Fluent<A>{
  public A addToAllow(Integer index,AllowDenyItem item);
  public A setToAllow(Integer index,AllowDenyItem item);
  public A addToAllow(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... items);
  public A addAllToAllow(Collection<AllowDenyItem> items);
  public A removeFromAllow(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... items);
  public A removeAllFromAllow(Collection<AllowDenyItem> items);
  public A removeMatchingFromAllow(Predicate<AllowDenyItemBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAllow instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AllowDenyItem> getAllow();
  public List<AllowDenyItem> buildAllow();
  public AllowDenyItem buildAllow(Integer index);
  public AllowDenyItem buildFirstAllow();
  public AllowDenyItem buildLastAllow();
  public AllowDenyItem buildMatchingAllow(Predicate<AllowDenyItemBuilder> predicate);
  public Boolean hasMatchingAllow(Predicate<AllowDenyItemBuilder> predicate);
  public A withAllow(List<AllowDenyItem> allow);
  public A withAllow(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... allow);
  public Boolean hasAllow();
  public SubscriptionSpecFluent.AllowNested<A> addNewAllow();
  public SubscriptionSpecFluent.AllowNested<A> addNewAllowLike(AllowDenyItem item);
  public SubscriptionSpecFluent.AllowNested<A> setNewAllowLike(Integer index,AllowDenyItem item);
  public SubscriptionSpecFluent.AllowNested<A> editAllow(Integer index);
  public SubscriptionSpecFluent.AllowNested<A> editFirstAllow();
  public SubscriptionSpecFluent.AllowNested<A> editLastAllow();
  public SubscriptionSpecFluent.AllowNested<A> editMatchingAllow(Predicate<AllowDenyItemBuilder> predicate);
  public String getChannel();
  public A withChannel(String channel);
  public Boolean hasChannel();
  public A addToDeny(Integer index,AllowDenyItem item);
  public A setToDeny(Integer index,AllowDenyItem item);
  public A addToDeny(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... items);
  public A addAllToDeny(Collection<AllowDenyItem> items);
  public A removeFromDeny(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... items);
  public A removeAllFromDeny(Collection<AllowDenyItem> items);
  public A removeMatchingFromDeny(Predicate<AllowDenyItemBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDeny instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AllowDenyItem> getDeny();
  public List<AllowDenyItem> buildDeny();
  public AllowDenyItem buildDeny(Integer index);
  public AllowDenyItem buildFirstDeny();
  public AllowDenyItem buildLastDeny();
  public AllowDenyItem buildMatchingDeny(Predicate<AllowDenyItemBuilder> predicate);
  public Boolean hasMatchingDeny(Predicate<AllowDenyItemBuilder> predicate);
  public A withDeny(List<AllowDenyItem> deny);
  public A withDeny(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... deny);
  public Boolean hasDeny();
  public SubscriptionSpecFluent.DenyNested<A> addNewDeny();
  public SubscriptionSpecFluent.DenyNested<A> addNewDenyLike(AllowDenyItem item);
  public SubscriptionSpecFluent.DenyNested<A> setNewDenyLike(Integer index,AllowDenyItem item);
  public SubscriptionSpecFluent.DenyNested<A> editDeny(Integer index);
  public SubscriptionSpecFluent.DenyNested<A> editFirstDeny();
  public SubscriptionSpecFluent.DenyNested<A> editLastDeny();
  public SubscriptionSpecFluent.DenyNested<A> editMatchingDeny(Predicate<AllowDenyItemBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHooksecretref instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getHooksecretref();
  public ObjectReference buildHooksecretref();
  public A withHooksecretref(ObjectReference hooksecretref);
  public Boolean hasHooksecretref();
  public SubscriptionSpecFluent.HooksecretrefNested<A> withNewHooksecretref();
  public SubscriptionSpecFluent.HooksecretrefNested<A> withNewHooksecretrefLike(ObjectReference item);
  public SubscriptionSpecFluent.HooksecretrefNested<A> editHooksecretref();
  public SubscriptionSpecFluent.HooksecretrefNested<A> editOrNewHooksecretref();
  public SubscriptionSpecFluent.HooksecretrefNested<A> editOrNewHooksecretrefLike(ObjectReference item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public A addToOverrides(Integer index,ClusterOverrides item);
  public A setToOverrides(Integer index,ClusterOverrides item);
  public A addToOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.ClusterOverrides... items);
  public A addAllToOverrides(Collection<ClusterOverrides> items);
  public A removeFromOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.ClusterOverrides... items);
  public A removeAllFromOverrides(Collection<ClusterOverrides> items);
  public A removeMatchingFromOverrides(Predicate<ClusterOverridesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterOverrides> getOverrides();
  public List<ClusterOverrides> buildOverrides();
  public ClusterOverrides buildOverride(Integer index);
  public ClusterOverrides buildFirstOverride();
  public ClusterOverrides buildLastOverride();
  public ClusterOverrides buildMatchingOverride(Predicate<ClusterOverridesBuilder> predicate);
  public Boolean hasMatchingOverride(Predicate<ClusterOverridesBuilder> predicate);
  public A withOverrides(List<ClusterOverrides> overrides);
  public A withOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.ClusterOverrides... overrides);
  public Boolean hasOverrides();
  public SubscriptionSpecFluent.OverridesNested<A> addNewOverride();
  public SubscriptionSpecFluent.OverridesNested<A> addNewOverrideLike(ClusterOverrides item);
  public SubscriptionSpecFluent.OverridesNested<A> setNewOverrideLike(Integer index,ClusterOverrides item);
  public SubscriptionSpecFluent.OverridesNested<A> editOverride(Integer index);
  public SubscriptionSpecFluent.OverridesNested<A> editFirstOverride();
  public SubscriptionSpecFluent.OverridesNested<A> editLastOverride();
  public SubscriptionSpecFluent.OverridesNested<A> editMatchingOverride(Predicate<ClusterOverridesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPackageFilter instead.
   * @return The buildable object.
   */
  @Deprecated
  public PackageFilter getPackageFilter();
  public PackageFilter buildPackageFilter();
  public A withPackageFilter(PackageFilter packageFilter);
  public Boolean hasPackageFilter();
  public SubscriptionSpecFluent.PackageFilterNested<A> withNewPackageFilter();
  public SubscriptionSpecFluent.PackageFilterNested<A> withNewPackageFilterLike(PackageFilter item);
  public SubscriptionSpecFluent.PackageFilterNested<A> editPackageFilter();
  public SubscriptionSpecFluent.PackageFilterNested<A> editOrNewPackageFilter();
  public SubscriptionSpecFluent.PackageFilterNested<A> editOrNewPackageFilterLike(PackageFilter item);
  public A addToPackageOverrides(Integer index,Overrides item);
  public A setToPackageOverrides(Integer index,Overrides item);
  public A addToPackageOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.Overrides... items);
  public A addAllToPackageOverrides(Collection<Overrides> items);
  public A removeFromPackageOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.Overrides... items);
  public A removeAllFromPackageOverrides(Collection<Overrides> items);
  public A removeMatchingFromPackageOverrides(Predicate<OverridesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPackageOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Overrides> getPackageOverrides();
  public List<Overrides> buildPackageOverrides();
  public Overrides buildPackageOverride(Integer index);
  public Overrides buildFirstPackageOverride();
  public Overrides buildLastPackageOverride();
  public Overrides buildMatchingPackageOverride(Predicate<OverridesBuilder> predicate);
  public Boolean hasMatchingPackageOverride(Predicate<OverridesBuilder> predicate);
  public A withPackageOverrides(List<Overrides> packageOverrides);
  public A withPackageOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.Overrides... packageOverrides);
  public Boolean hasPackageOverrides();
  public SubscriptionSpecFluent.PackageOverridesNested<A> addNewPackageOverride();
  public SubscriptionSpecFluent.PackageOverridesNested<A> addNewPackageOverrideLike(Overrides item);
  public SubscriptionSpecFluent.PackageOverridesNested<A> setNewPackageOverrideLike(Integer index,Overrides item);
  public SubscriptionSpecFluent.PackageOverridesNested<A> editPackageOverride(Integer index);
  public SubscriptionSpecFluent.PackageOverridesNested<A> editFirstPackageOverride();
  public SubscriptionSpecFluent.PackageOverridesNested<A> editLastPackageOverride();
  public SubscriptionSpecFluent.PackageOverridesNested<A> editMatchingPackageOverride(Predicate<OverridesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPlacement instead.
   * @return The buildable object.
   */
  @Deprecated
  public Placement getPlacement();
  public Placement buildPlacement();
  public A withPlacement(Placement placement);
  public Boolean hasPlacement();
  public SubscriptionSpecFluent.PlacementNested<A> withNewPlacement();
  public SubscriptionSpecFluent.PlacementNested<A> withNewPlacementLike(Placement item);
  public SubscriptionSpecFluent.PlacementNested<A> editPlacement();
  public SubscriptionSpecFluent.PlacementNested<A> editOrNewPlacement();
  public SubscriptionSpecFluent.PlacementNested<A> editOrNewPlacementLike(Placement item);
  public String getSecondaryChannel();
  public A withSecondaryChannel(String secondaryChannel);
  public Boolean hasSecondaryChannel();
  
  /**
   * This method has been deprecated, please use method buildTimewindow instead.
   * @return The buildable object.
   */
  @Deprecated
  public TimeWindow getTimewindow();
  public TimeWindow buildTimewindow();
  public A withTimewindow(TimeWindow timewindow);
  public Boolean hasTimewindow();
  public SubscriptionSpecFluent.TimewindowNested<A> withNewTimewindow();
  public SubscriptionSpecFluent.TimewindowNested<A> withNewTimewindowLike(TimeWindow item);
  public SubscriptionSpecFluent.TimewindowNested<A> editTimewindow();
  public SubscriptionSpecFluent.TimewindowNested<A> editOrNewTimewindow();
  public SubscriptionSpecFluent.TimewindowNested<A> editOrNewTimewindowLike(TimeWindow item);
  public interface AllowNested<N> extends Nested<N>,AllowDenyItemFluent<SubscriptionSpecFluent.AllowNested<N>>{
    public N and();
    public N endAllow();
    
  }
  public interface DenyNested<N> extends Nested<N>,AllowDenyItemFluent<SubscriptionSpecFluent.DenyNested<N>>{
    public N and();
    public N endDeny();
    
  }
  public interface HooksecretrefNested<N> extends Nested<N>,ObjectReferenceFluent<SubscriptionSpecFluent.HooksecretrefNested<N>>{
    public N and();
    public N endHooksecretref();
    
  }
  public interface OverridesNested<N> extends Nested<N>,ClusterOverridesFluent<SubscriptionSpecFluent.OverridesNested<N>>{
    public N and();
    public N endOverride();
    
  }
  public interface PackageFilterNested<N> extends Nested<N>,PackageFilterFluent<SubscriptionSpecFluent.PackageFilterNested<N>>{
    public N and();
    public N endPackageFilter();
    
  }
  public interface PackageOverridesNested<N> extends Nested<N>,OverridesFluent<SubscriptionSpecFluent.PackageOverridesNested<N>>{
    public N and();
    public N endPackageOverride();
    
  }
  public interface PlacementNested<N> extends Nested<N>,PlacementFluent<SubscriptionSpecFluent.PlacementNested<N>>{
    public N and();
    public N endPlacement();
    
  }
  public interface TimewindowNested<N> extends Nested<N>,TimeWindowFluent<SubscriptionSpecFluent.TimewindowNested<N>>{
    public N and();
    public N endTimewindow();
    
  }
  
}

==> open-cluster-management-apps-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/SubscriptionSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1.Placement;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.placementrule.v1.PlacementFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.util.Collection;

 /**
  * Generated
  */
public interface SubscriptionSpecFluent<A extends SubscriptionSpecFluent<A>> extends Fluent<A>{
  public A addToAllow(int index,AllowDenyItem item);
  public A setToAllow(int index,AllowDenyItem item);
  public A addToAllow(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... items);
  public A addAllToAllow(Collection<AllowDenyItem> items);
  public A removeFromAllow(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... items);
  public A removeAllFromAllow(Collection<AllowDenyItem> items);
  public A removeMatchingFromAllow(Predicate<AllowDenyItemBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAllow instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AllowDenyItem> getAllow();
  public List<AllowDenyItem> buildAllow();
  public AllowDenyItem buildAllow(int index);
  public AllowDenyItem buildFirstAllow();
  public AllowDenyItem buildLastAllow();
  public AllowDenyItem buildMatchingAllow(Predicate<AllowDenyItemBuilder> predicate);
  public Boolean hasMatchingAllow(Predicate<AllowDenyItemBuilder> predicate);
  public A withAllow(List<AllowDenyItem> allow);
  public A withAllow(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... allow);
  public Boolean hasAllow();
  public SubscriptionSpecFluent.AllowNested<A> addNewAllow();
  public SubscriptionSpecFluent.AllowNested<A> addNewAllowLike(AllowDenyItem item);
  public SubscriptionSpecFluent.AllowNested<A> setNewAllowLike(int index,AllowDenyItem item);
  public SubscriptionSpecFluent.AllowNested<A> editAllow(int index);
  public SubscriptionSpecFluent.AllowNested<A> editFirstAllow();
  public SubscriptionSpecFluent.AllowNested<A> editLastAllow();
  public SubscriptionSpecFluent.AllowNested<A> editMatchingAllow(Predicate<AllowDenyItemBuilder> predicate);
  public String getChannel();
  public A withChannel(String channel);
  public Boolean hasChannel();
  public A addToDeny(int index,AllowDenyItem item);
  public A setToDeny(int index,AllowDenyItem item);
  public A addToDeny(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... items);
  public A addAllToDeny(Collection<AllowDenyItem> items);
  public A removeFromDeny(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... items);
  public A removeAllFromDeny(Collection<AllowDenyItem> items);
  public A removeMatchingFromDeny(Predicate<AllowDenyItemBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDeny instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AllowDenyItem> getDeny();
  public List<AllowDenyItem> buildDeny();
  public AllowDenyItem buildDeny(int index);
  public AllowDenyItem buildFirstDeny();
  public AllowDenyItem buildLastDeny();
  public AllowDenyItem buildMatchingDeny(Predicate<AllowDenyItemBuilder> predicate);
  public Boolean hasMatchingDeny(Predicate<AllowDenyItemBuilder> predicate);
  public A withDeny(List<AllowDenyItem> deny);
  public A withDeny(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.AllowDenyItem... deny);
  public Boolean hasDeny();
  public SubscriptionSpecFluent.DenyNested<A> addNewDeny();
  public SubscriptionSpecFluent.DenyNested<A> addNewDenyLike(AllowDenyItem item);
  public SubscriptionSpecFluent.DenyNested<A> setNewDenyLike(int index,AllowDenyItem item);
  public SubscriptionSpecFluent.DenyNested<A> editDeny(int index);
  public SubscriptionSpecFluent.DenyNested<A> editFirstDeny();
  public SubscriptionSpecFluent.DenyNested<A> editLastDeny();
  public SubscriptionSpecFluent.DenyNested<A> editMatchingDeny(Predicate<AllowDenyItemBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildHooksecretref instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getHooksecretref();
  public ObjectReference buildHooksecretref();
  public A withHooksecretref(ObjectReference hooksecretref);
  public Boolean hasHooksecretref();
  public SubscriptionSpecFluent.HooksecretrefNested<A> withNewHooksecretref();
  public SubscriptionSpecFluent.HooksecretrefNested<A> withNewHooksecretrefLike(ObjectReference item);
  public SubscriptionSpecFluent.HooksecretrefNested<A> editHooksecretref();
  public SubscriptionSpecFluent.HooksecretrefNested<A> editOrNewHooksecretref();
  public SubscriptionSpecFluent.HooksecretrefNested<A> editOrNewHooksecretrefLike(ObjectReference item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public A addToOverrides(int index,ClusterOverrides item);
  public A setToOverrides(int index,ClusterOverrides item);
  public A addToOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.ClusterOverrides... items);
  public A addAllToOverrides(Collection<ClusterOverrides> items);
  public A removeFromOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.ClusterOverrides... items);
  public A removeAllFromOverrides(Collection<ClusterOverrides> items);
  public A removeMatchingFromOverrides(Predicate<ClusterOverridesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterOverrides> getOverrides();
  public List<ClusterOverrides> buildOverrides();
  public ClusterOverrides buildOverride(int index);
  public ClusterOverrides buildFirstOverride();
  public ClusterOverrides buildLastOverride();
  public ClusterOverrides buildMatchingOverride(Predicate<ClusterOverridesBuilder> predicate);
  public Boolean hasMatchingOverride(Predicate<ClusterOverridesBuilder> predicate);
  public A withOverrides(List<ClusterOverrides> overrides);
  public A withOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.ClusterOverrides... overrides);
  public Boolean hasOverrides();
  public SubscriptionSpecFluent.OverridesNested<A> addNewOverride();
  public SubscriptionSpecFluent.OverridesNested<A> addNewOverrideLike(ClusterOverrides item);
  public SubscriptionSpecFluent.OverridesNested<A> setNewOverrideLike(int index,ClusterOverrides item);
  public SubscriptionSpecFluent.OverridesNested<A> editOverride(int index);
  public SubscriptionSpecFluent.OverridesNested<A> editFirstOverride();
  public SubscriptionSpecFluent.OverridesNested<A> editLastOverride();
  public SubscriptionSpecFluent.OverridesNested<A> editMatchingOverride(Predicate<ClusterOverridesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPackageFilter instead.
   * @return The buildable object.
   */
  @Deprecated
  public PackageFilter getPackageFilter();
  public PackageFilter buildPackageFilter();
  public A withPackageFilter(PackageFilter packageFilter);
  public Boolean hasPackageFilter();
  public SubscriptionSpecFluent.PackageFilterNested<A> withNewPackageFilter();
  public SubscriptionSpecFluent.PackageFilterNested<A> withNewPackageFilterLike(PackageFilter item);
  public SubscriptionSpecFluent.PackageFilterNested<A> editPackageFilter();
  public SubscriptionSpecFluent.PackageFilterNested<A> editOrNewPackageFilter();
  public SubscriptionSpecFluent.PackageFilterNested<A> editOrNewPackageFilterLike(PackageFilter item);
  public A addToPackageOverrides(int index,Overrides item);
  public A setToPackageOverrides(int index,Overrides item);
  public A addToPackageOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.Overrides... items);
  public A addAllToPackageOverrides(Collection<Overrides> items);
  public A removeFromPackageOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.Overrides... items);
  public A removeAllFromPackageOverrides(Collection<Overrides> items);
  public A removeMatchingFromPackageOverrides(Predicate<OverridesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPackageOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Overrides> getPackageOverrides();
  public List<Overrides> buildPackageOverrides();
  public Overrides buildPackageOverride(int index);
  public Overrides buildFirstPackageOverride();
  public Overrides buildLastPackageOverride();
  public Overrides buildMatchingPackageOverride(Predicate<OverridesBuilder> predicate);
  public Boolean hasMatchingPackageOverride(Predicate<OverridesBuilder> predicate);
  public A withPackageOverrides(List<Overrides> packageOverrides);
  public A withPackageOverrides(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1.Overrides... packageOverrides);
  public Boolean hasPackageOverrides();
  public SubscriptionSpecFluent.PackageOverridesNested<A> addNewPackageOverride();
  public SubscriptionSpecFluent.PackageOverridesNested<A> addNewPackageOverrideLike(Overrides item);
  public SubscriptionSpecFluent.PackageOverridesNested<A> setNewPackageOverrideLike(int index,Overrides item);
  public SubscriptionSpecFluent.PackageOverridesNested<A> editPackageOverride(int index);
  public SubscriptionSpecFluent.PackageOverridesNested<A> editFirstPackageOverride();
  public SubscriptionSpecFluent.PackageOverridesNested<A> editLastPackageOverride();
  public SubscriptionSpecFluent.PackageOverridesNested<A> editMatchingPackageOverride(Predicate<OverridesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPlacement instead.
   * @return The buildable object.
   */
  @Deprecated
  public Placement getPlacement();
  public Placement buildPlacement();
  public A withPlacement(Placement placement);
  public Boolean hasPlacement();
  public SubscriptionSpecFluent.PlacementNested<A> withNewPlacement();
  public SubscriptionSpecFluent.PlacementNested<A> withNewPlacementLike(Placement item);
  public SubscriptionSpecFluent.PlacementNested<A> editPlacement();
  public SubscriptionSpecFluent.PlacementNested<A> editOrNewPlacement();
  public SubscriptionSpecFluent.PlacementNested<A> editOrNewPlacementLike(Placement item);
  public String getSecondaryChannel();
  public A withSecondaryChannel(String secondaryChannel);
  public Boolean hasSecondaryChannel();
  
  /**
   * This method has been deprecated, please use method buildTimewindow instead.
   * @return The buildable object.
   */
  @Deprecated
  public TimeWindow getTimewindow();
  public TimeWindow buildTimewindow();
  public A withTimewindow(TimeWindow timewindow);
  public Boolean hasTimewindow();
  public SubscriptionSpecFluent.TimewindowNested<A> withNewTimewindow();
  public SubscriptionSpecFluent.TimewindowNested<A> withNewTimewindowLike(TimeWindow item);
  public SubscriptionSpecFluent.TimewindowNested<A> editTimewindow();
  public SubscriptionSpecFluent.TimewindowNested<A> editOrNewTimewindow();
  public SubscriptionSpecFluent.TimewindowNested<A> editOrNewTimewindowLike(TimeWindow item);
  public interface AllowNested<N> extends Nested<N>,AllowDenyItemFluent<SubscriptionSpecFluent.AllowNested<N>>{
    public N and();
    public N endAllow();
    
  }
  public interface DenyNested<N> extends Nested<N>,AllowDenyItemFluent<SubscriptionSpecFluent.DenyNested<N>>{
    public N and();
    public N endDeny();
    
  }
  public interface HooksecretrefNested<N> extends Nested<N>,ObjectReferenceFluent<SubscriptionSpecFluent.HooksecretrefNested<N>>{
    public N and();
    public N endHooksecretref();
    
  }
  public interface OverridesNested<N> extends Nested<N>,ClusterOverridesFluent<SubscriptionSpecFluent.OverridesNested<N>>{
    public N and();
    public N endOverride();
    
  }
  public interface PackageFilterNested<N> extends Nested<N>,PackageFilterFluent<SubscriptionSpecFluent.PackageFilterNested<N>>{
    public N and();
    public N endPackageFilter();
    
  }
  public interface PackageOverridesNested<N> extends Nested<N>,OverridesFluent<SubscriptionSpecFluent.PackageOverridesNested<N>>{
    public N and();
    public N endPackageOverride();
    
  }
  public interface PlacementNested<N> extends Nested<N>,PlacementFluent<SubscriptionSpecFluent.PlacementNested<N>>{
    public N and();
    public N endPlacement();
    
  }
  public interface TimewindowNested<N> extends Nested<N>,TimeWindowFluent<SubscriptionSpecFluent.TimewindowNested<N>>{
    public N and();
    public N endTimewindow();
    
  }
  
}
